.. _pymochad_api:

PyMochad API
============

The PyMochad Controller Class
-----------------------------
This is used to interact with the X10 controller directly using the mochad
socket

.. automodule:: pymochad.controller
   :members:
   :undoc-members:
   :show-inheritance:

The PyMochad Device Class
-------------------------
This is used to interact with an X10 device

.. automodule:: pymochad.device
   :members:
   :undoc-members:
   :show-inheritance:
